package com.jjt.biz.controller;

import com.jjt.biz.domain.HlBase;
import com.jjt.biz.service.IHlBaseService;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.enums.BusinessType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;

/**
 * 模型健康度配置Controller
 *
 * @author jjt
 * @date 2024-08-28
 */
@Api(tags = "模型健康度配置")
@RestController
@RequestMapping("/hl/hlb")
public class HlBaseController extends BaseController {
    @Resource
    private IHlBaseService hlBaseService;

    /**
     * 获取模型健康度配置详细信息
     */
    @ApiOperation("获取模型健康度配置详细信息")
    @GetMapping(value = "/{modelId}")
    public AjaxResult getInfo(@PathVariable("modelId") Long modelId) {
        HlBase base = hlBaseService.selectHlBaseByModelId(modelId);
        return success(base);
    }

    /**
     * 获取模型健康度配置详细信息
     */
    @ApiOperation("根据模型ID删除健康度配置")
    @DeleteMapping(value = "/{modelId}")
    public AjaxResult delete(@PathVariable("modelId") Long modelId) {
        hlBaseService.deleteHlBase4ModelId(modelId);
        return AjaxResult.success();
    }


    @ApiOperation("修改模型健康度配置")
    @PreAuthorize("@ss.hasPermi('hl:hlb:edit')")
    @Log(title = "模型健康度配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody HlBase hlBase) {
        return toAjax(hlBaseService.updateHlBase(hlBase));
    }
}
