package com.jjt.biz.controller;

import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.enums.BusinessType;
import com.jjt.biz.domain.HlClass;
import com.jjt.biz.service.IHlClassService;
import com.jjt.common.utils.poi.ExcelUtil;
import com.jjt.common.core.page.TableDataInfo;

/**
 * 健康度分类Controller
 *
 * @author jjt
 * @date 2024-08-28
 */
@Api(tags="健康度分类")
@RestController
@RequestMapping("/hl/hlc")
public class HlClassController extends BaseController
{
    @Resource
    private IHlClassService hlClassService;

    /**
     * 查询健康度分类列表
     */
    @ApiOperation("查询健康度分类列表")
    @PreAuthorize("@ss.hasPermi('hl:hlc:list')")
    @GetMapping("/list")
    public TableDataInfo list(HlClass hlClass)
    {
        startPage();
        List<HlClass> list = hlClassService.selectHlClassList(hlClass);
        return getDataTable(list);
    }

    /**
     * 导出健康度分类列表
     */
    @ApiOperation("导出健康度分类列表")
    @PreAuthorize("@ss.hasPermi('hl:hlc:export')")
    @Log(title = "健康度分类", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, HlClass hlClass)
    {
        List<HlClass> list = hlClassService.selectHlClassList(hlClass);
        ExcelUtil<HlClass> util = new ExcelUtil<HlClass>(HlClass.class);
        util.exportExcel(response, list, "健康度分类数据");
    }

    /**
     * 获取健康度分类详细信息
     */
    @ApiOperation("获取健康度分类详细信息")
    @PreAuthorize("@ss.hasPermi('hl:hlc:query')")
    @GetMapping(value = "/{classId}")
    public AjaxResult getInfo(@PathVariable("classId") Long classId)
    {
        return success(hlClassService.selectHlClassByClassId(classId));
    }

    /**
     * 新增健康度分类
     */
    @ApiOperation("新增健康度分类")
    @PreAuthorize("@ss.hasPermi('hl:hlc:add')")
    @Log(title = "健康度分类", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody HlClass hlClass)
    {
        return toAjax(hlClassService.insertHlClass(hlClass));
    }

    /**
     * 修改健康度分类
     */
    @ApiOperation("修改健康度分类")
    @PreAuthorize("@ss.hasPermi('hl:hlc:edit')")
    @Log(title = "健康度分类", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody HlClass hlClass)
    {
        return toAjax(hlClassService.updateHlClass(hlClass));
    }

    /**
     * 删除健康度分类
     */
    @ApiOperation("删除健康度分类")
    @PreAuthorize("@ss.hasPermi('hl:hlc:remove')")
    @Log(title = "健康度分类", businessType = BusinessType.DELETE)
	@DeleteMapping("/{classIds}")
    public AjaxResult remove(@PathVariable Long[] classIds)
    {
        return toAjax(hlClassService.deleteHlClassByClassIds(classIds));
    }
}
