package com.jjt.biz.controller;

import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.enums.BusinessType;
import com.jjt.biz.domain.HlDetail;
import com.jjt.biz.service.IHlDetailService;
import com.jjt.common.utils.poi.ExcelUtil;
import com.jjt.common.core.page.TableDataInfo;

/**
 * 健康度明细Controller
 *
 * @author jjt
 * @date 2024-08-28
 */
@Api(tags="健康度明细")
@RestController
@RequestMapping("/hl/hld")
public class HlDetailController extends BaseController
{
    @Resource
    private IHlDetailService hlDetailService;

    /**
     * 查询健康度明细列表
     */
    @ApiOperation("查询健康度明细列表")
    @PreAuthorize("@ss.hasPermi('hl:hld:list')")
    @GetMapping("/list")
    public TableDataInfo list(HlDetail hlDetail)
    {
        startPage();
        List<HlDetail> list = hlDetailService.selectHlDetailList(hlDetail);
        return getDataTable(list);
    }

    /**
     * 导出健康度明细列表
     */
    @ApiOperation("导出健康度明细列表")
    @PreAuthorize("@ss.hasPermi('hl:hld:export')")
    @Log(title = "健康度明细", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, HlDetail hlDetail)
    {
        List<HlDetail> list = hlDetailService.selectHlDetailList(hlDetail);
        ExcelUtil<HlDetail> util = new ExcelUtil<HlDetail>(HlDetail.class);
        util.exportExcel(response, list, "健康度明细数据");
    }

    /**
     * 获取健康度明细详细信息
     */
    @ApiOperation("获取健康度明细详细信息")
    @PreAuthorize("@ss.hasPermi('hl:hld:query')")
    @GetMapping(value = "/{hlDetailId}")
    public AjaxResult getInfo(@PathVariable("hlDetailId") Long hlDetailId)
    {
        return success(hlDetailService.selectHlDetailByHlDetailId(hlDetailId));
    }

    /**
     * 新增健康度明细
     */
    @ApiOperation("新增健康度明细")
    @PreAuthorize("@ss.hasPermi('hl:hld:add')")
    @Log(title = "健康度明细", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody HlDetail hlDetail)
    {
        return toAjax(hlDetailService.insertHlDetail(hlDetail));
    }

    /**
     * 修改健康度明细
     */
    @ApiOperation("修改健康度明细")
    @PreAuthorize("@ss.hasPermi('hl:hld:edit')")
    @Log(title = "健康度明细", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody HlDetail hlDetail)
    {
        return toAjax(hlDetailService.updateHlDetail(hlDetail));
    }

    /**
     * 删除健康度明细
     */
    @ApiOperation("删除健康度明细")
    @PreAuthorize("@ss.hasPermi('hl:hld:remove')")
    @Log(title = "健康度明细", businessType = BusinessType.DELETE)
	@DeleteMapping("/{hlDetailIds}")
    public AjaxResult remove(@PathVariable Long[] hlDetailIds)
    {
        return toAjax(hlDetailService.deleteHlDetailByHlDetailIds(hlDetailIds));
    }
}
