package com.jjt.biz.controller;

import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.enums.BusinessType;
import com.jjt.biz.domain.HlObj;
import com.jjt.biz.service.IHlObjService;
import com.jjt.common.utils.poi.ExcelUtil;
import com.jjt.common.core.page.TableDataInfo;

/**
 * 健康度对象Controller
 *
 * @author jjt
 * @date 2024-08-28
 */
@Api(tags="健康度对象")
@RestController
@RequestMapping("/hl/hlo")
public class HlObjController extends BaseController
{
    @Resource
    private IHlObjService hlObjService;

    /**
     * 查询健康度对象列表
     */
    @ApiOperation("查询健康度对象列表")
    @PreAuthorize("@ss.hasPermi('hl:hlo:list')")
    @GetMapping("/list")
    public TableDataInfo list(HlObj hlObj)
    {
        startPage();
        List<HlObj> list = hlObjService.selectHlObjList(hlObj);
        return getDataTable(list);
    }

    /**
     * 导出健康度对象列表
     */
    @ApiOperation("导出健康度对象列表")
    @PreAuthorize("@ss.hasPermi('hl:hlo:export')")
    @Log(title = "健康度对象", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, HlObj hlObj)
    {
        List<HlObj> list = hlObjService.selectHlObjList(hlObj);
        ExcelUtil<HlObj> util = new ExcelUtil<HlObj>(HlObj.class);
        util.exportExcel(response, list, "健康度对象数据");
    }

    /**
     * 获取健康度对象详细信息
     */
    @ApiOperation("获取健康度对象详细信息")
    @PreAuthorize("@ss.hasPermi('hl:hlo:query')")
    @GetMapping(value = "/{hlObjId}")
    public AjaxResult getInfo(@PathVariable("hlObjId") Long hlObjId)
    {
        return success(hlObjService.selectHlObjByHlObjId(hlObjId));
    }

    /**
     * 新增健康度对象
     */
    @ApiOperation("新增健康度对象")
    @PreAuthorize("@ss.hasPermi('hl:hlo:add')")
    @Log(title = "健康度对象", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody HlObj hlObj)
    {
        return toAjax(hlObjService.insertHlObj(hlObj));
    }

    /**
     * 修改健康度对象
     */
    @ApiOperation("修改健康度对象")
    @PreAuthorize("@ss.hasPermi('hl:hlo:edit')")
    @Log(title = "健康度对象", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody HlObj hlObj)
    {
        return toAjax(hlObjService.updateHlObj(hlObj));
    }

    /**
     * 删除健康度对象
     */
    @ApiOperation("删除健康度对象")
    @PreAuthorize("@ss.hasPermi('hl:hlo:remove')")
    @Log(title = "健康度对象", businessType = BusinessType.DELETE)
	@DeleteMapping("/{hlObjIds}")
    public AjaxResult remove(@PathVariable Long[] hlObjIds)
    {
        return toAjax(hlObjService.deleteHlObjByHlObjIds(hlObjIds));
    }
}
